bayespy.inference.vmp.nodes.stochastic.Distribution.random
==========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Distribution.random